@@ -12,7 +12,7 @@ my $psu = Electronics::PSU::DPSxxxx->new( dev => "/dev/ttyUSB0" );
 
 printf "DPS%d, version %d\n", await $psu->read_model, await $psu->read_version;
 
-printf "Supply voltage: %.2fV\n", await $psu->measure_input_voltage;
+printf "Supply voltage: %.2fV\n", await $psu->read_input_voltage;
 
 await $psu->set_voltage( shift @ARGV or 10.22 );
 await $psu->set_current( shift @ARGV or 0.456 );
@@ -23,7 +23,6 @@ $SIG{INT} = $SIG{TERM} = sub { exit };
 END { $psu->set_output_state( 0 )->get; }
 
 while(1) {
-   printf "Output: %.2fV; %0.3fA\n",
-      await $psu->measure_output_voltage,
-      await $psu->measure_output_current;
+   printf "Output: %.2fV; %0.3fA %s\n",
+      await $psu->read_multiple(qw( output_voltage output_current output_mode ));
 }
